import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { select, axisLeft, axisBottom, csv, arc, pie, scaleBand, scaleLinear, max, format} from 'd3';

const titleText = 'Top 10 Most Populous Countries';
const xAxisLabelText = 'Population';

const csvUrl =
  "https://gist.githubusercontent.com/yamunayennem/d4304838e08f5970f06be793d3576d97/raw/4a9d01b1086db4031a7fe426df159a8439ca8fbf/covid-deaths"
const width = 1000;
const height = 1000;
const margin = {top: 50, right: 40, bottom: 77, left: 180};


const App = () => {
  const [data, setData] = useState(null);

  useEffect(() => {
    const row = d => {
      d.deaths = +d['Total Deaths'];
      return d;
    };
    csv(csvUrl, row).then(data => {
      setData(data.slice(0, 5));
    });
  }, []);

  if (!data) {
    return <pre>Loading...</pre>;
  }

  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;
 

  const yScale = scaleBand()
    .domain(data.map(d => d.Country))
    .range([0, innerHeight]);

  const xScale = scaleLinear()
    .domain([0, max(data, d => d.deaths)])
    .range([0, innerWidth]);

  return (
    <svg width={width} height={height}>
      <g transform={`translate(${margin.left},${margin.top})`}>
        {xScale.ticks().map(tickValue => (
          <g key={tickValue} transform={`translate(${xScale(tickValue)},0)`}>
            <line y2={innerHeight} stroke="red" />
            <text
              style={{ textAnchor: 'middle' }}
              dy=".70em"
              y={innerHeight + 2}
            >
              {tickValue}
            </text>
          </g>
        ))}
        {yScale.domain().map(tickValue => (
          <text
            key={tickValue}
            style={{ textAnchor: 'end' }}
            x={-10}
            dy=".12em"
            y={yScale(tickValue) + yScale.bandwidth() / 2}
          >
            {tickValue}
          </text>
        ))}
        {data.map(d => (
          <rect
            key={d.Country}
            x={0}
            y={yScale(d.Country)}
            width={xScale(d.deaths)}
            height={yScale.bandwidth()}
          />
        ))}
      </g>
    </svg>
  );
};

  
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);